@@ -68,11 +68,11 @@ class daemonprocess {
 		int	runAsUserId(uid_t uid) const;
 		int	runAsGroupId(gid_t gid) const;
 
-		static	void	handleShutDown(void *shutdownfunction);
+		static	void	handleShutDown(void (*shutdownfunction)(int));
 				// This method allows you to designate a
 				// function to run when the daemon is killed.
 
-		static	void	handleCrash(void *crashfunction);
+		static	void	handleCrash(void (*crashfunction)(int));
 				// This method allows you to designate a
 				// function to run if the daemon crashes.
 
