@@ -253,7 +253,7 @@ class filedescriptor {
 		ssize_t	read(void *buf, size_t size) const;
 				// Reads "size" bytes from the file descriptor
 				// into "buffer".
-		ssize_t	read(char **buffer, char *terminator) const;
+		ssize_t	read(char **buffer, const char *terminator) const;
 				// Reads from the file desciptor into "buffer"
 				// until "terminator" is encountered.  Note
 				// that "buffer" is allocated internally and
@@ -311,7 +311,7 @@ class filedescriptor {
 					long sec, long usec) const;
 				// Reads "size" bytes from the file descriptor
 				// into "buffer".
-		ssize_t	read(char **buffer, char *terminator,
+		ssize_t	read(char **buffer, const char *terminator,
 					long sec, long usec) const;
 				// Reads from the file desciptor into "buffer"
 				// until "terminator" is encountered.  Note
@@ -538,6 +538,15 @@ class filedescriptor {
 				// Returns true if the close-on-exec status
 				// is set true and false otherwise.
 
+		// These methods convert from host to
+		// net byte order and vice-versa.
+		static	uint16_t	hostToNet(uint16_t value);
+		static	uint32_t	hostToNet(uint32_t value);
+		static	uint64_t	hostToNet(uint64_t value);
+		static	uint16_t	netToHost(uint16_t value);
+		static	uint32_t	netToHost(uint32_t value);
+		static	uint64_t	netToHost(uint64_t value);
+
 	#include <rudiments/private/filedescriptor.h>
 };
 
