@@ -18,12 +18,10 @@ class mutex {
 	public:
 			mutex();
 			// Initialize a mutex.
-			#if defined(RUDIMENTS_HAVE_PTHREAD_MUTEX_T)
+
 			mutex(pthread_mutex_t *mut);
-			#elif defined(RUDIMENTS_HAVE_CREATE_MUTEX)
-			mutex(HANDLE mut);
-			#endif
 			// Attach already initialized "mut" to this instance.
+
 			~mutex();
 			// Destroy the mutex.
 
@@ -39,13 +37,9 @@ class mutex {
 			// Unlock the mutex.
 			// Returns true on success and false if an error occurs.
 
-		#if defined(RUDIMENTS_HAVE_PTHREAD_MUTEX_T)
 		pthread_mutex_t	*getMutex();
-		#elif defined(RUDIMENTS_HAVE_CREATE_MUTEX)
-		HANDLE		getMutex();
-		#endif
-				// Returns the mutex used by
-				// the class internally.
+			// Returns the mutex used by
+			// the class internally.
 
 	#include <rudiments/private/mutex.h>
 };
