@@ -7,13 +7,6 @@
 		void	filedescriptorInit();
 		void	filedescriptorClone(const filedescriptor &f);
 
-		virtual	uint16_t	hostToNet(uint16_t value) const;
-		virtual	uint32_t	hostToNet(uint32_t value) const;
-		virtual	uint64_t	hostToNet(uint64_t value) const;
-		virtual	uint16_t	netToHost(uint16_t value) const;
-		virtual	uint32_t	netToHost(uint32_t value) const;
-		virtual	uint64_t	netToHost(uint64_t value) const;
-
 		virtual	ssize_t	bufferedRead(void *buf, ssize_t count,
 						long sec, long usec) const;
 		virtual	ssize_t	bufferedWrite(const void *buf, ssize_t count,
@@ -24,6 +17,8 @@
 						long sec, long usec) const;
 		virtual	int	safeSelect(long sec, long usec,
 						bool read, bool write) const;
+		virtual	int	safePoll(long sec, long usec,
+						bool read, bool write) const;
 		bool		setNoDelay(int onoff);
 
 		#ifdef RUDIMENTS_HAS_SSL
@@ -35,6 +30,12 @@
 		int	setSockOpt(int level, int optname,
 					const void *optval, socklen_t optlen);
 
+		virtual	ssize_t	lowLevelRead(void *buf,
+						ssize_t count) const;
+		virtual	ssize_t	lowLevelWrite(const void *buf,
+						ssize_t count) const;
+		virtual int	lowLevelClose();
+
 		const char	*type() const;
 		void		type(const char *tp);
 
