@@ -4,6 +4,5 @@
 #include <rudiments/private/inttypes.h>
 #include <rudiments/private/rudimentsinlines.h>
 
-// FIXME: can any of these be moved into math.C
-#include <math.h>
-#include <tgmath.h>
+#include <stdlib.h>
+#include <complex.h>
