@@ -1,12 +1,10 @@
 // Copyright (c) 1999-2002 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/private/inttypes.h>
-
-// for struct timespec
+// for struct timespec (it includes inttypes.h as well)
 #include <rudiments/private/snoozeincludes.h>
 
 #include <sys/types.h>
 
-// for struct sembuf
-#include <sys/sem.h>
+struct sembuf;
+union semun;
