@@ -6,6 +6,9 @@
 		BIO	*newSSLBIO() const;
 		bool	sslAccept(filedescriptor *sock);
 #endif
+		ssize_t	lowLevelRead(void *buf, ssize_t count) const;
+		ssize_t	lowLevelWrite(const void *buf, ssize_t count) const;
+		int	lowLevelClose();
 
 	private:
 		bool	setLingerOnClose(int timeout, int onoff);
