@@ -4,5 +4,9 @@
 #include <rudiments/private/inttypes.h>
 
 #include <sys/types.h>
-#include <sys/ipc.h>
-#include <sys/shm.h>
+#ifdef RUDIMENTS_HAVE_SHMGET
+	#include <sys/ipc.h>
+	#include <sys/shm.h>
+#else
+	typedef void shmid_ds;
+#endif
